@@ -44,6 +44,9 @@ def simple_logging(debug=False, http_debug=False):
         log = _log.setup_logging('keystoneauth')
         log.addHandler(logging.StreamHandler())
         log.setLevel(log_level)
+    # Simple case - we do not care about request id log
+    log = _log.setup_logging('shade.request_ids')
+    log.setLevel(logging.INFO)
     log = _log.setup_logging('shade')
     log.addHandler(logging.StreamHandler())
     log.setLevel(log_level)
@@ -52,7 +55,7 @@ def simple_logging(debug=False, http_debug=False):
     log = _log.setup_logging('keystoneauth.identity.generic.base')
 
 
-def openstack_clouds(config=None, debug=False, cloud=None):
+def openstack_clouds(config=None, debug=False, cloud=None, strict=False):
     if not config:
         config = os_client_config.OpenStackConfig()
     try:
@@ -61,6 +64,7 @@ def openstack_clouds(config=None, debug=False, cloud=None):
                 OpenStackCloud(
                     cloud=f.name, debug=debug,
                     cloud_config=f,
+                    strict=strict,
                     **f.config)
                 for f in config.get_all_clouds()
             ]
@@ -69,6 +73,7 @@ def openstack_clouds(config=None, debug=False, cloud=None):
                 OpenStackCloud(
                     cloud=f.name, debug=debug,
                     cloud_config=f,
+                    strict=strict,
                     **f.config)
                 for f in config.get_all_clouds()
                 if f.name == cloud
@@ -78,7 +83,7 @@ def openstack_clouds(config=None, debug=False, cloud=None):
             "Invalid cloud configuration: {exc}".format(exc=str(e)))
 
 
-def openstack_cloud(config=None, **kwargs):
+def openstack_cloud(config=None, strict=False, **kwargs):
     if not config:
         config = os_client_config.OpenStackConfig()
     try:
@@ -86,10 +91,10 @@ def openstack_cloud(config=None, **kwargs):
     except keystoneauth1.exceptions.auth_plugins.NoMatchingPlugin as e:
         raise OpenStackCloudException(
             "Invalid cloud configuration: {exc}".format(exc=str(e)))
-    return OpenStackCloud(cloud_config=cloud_config)
+    return OpenStackCloud(cloud_config=cloud_config, strict=strict)
 
 
-def operator_cloud(config=None, **kwargs):
+def operator_cloud(config=None, strict=False, **kwargs):
     if 'interface' not in kwargs:
         kwargs['interface'] = 'admin'
     if not config:
@@ -99,4 +104,4 @@ def operator_cloud(config=None, **kwargs):
     except keystoneauth1.exceptions.auth_plugins.NoMatchingPlugin as e:
         raise OpenStackCloudException(
             "Invalid cloud configuration: {exc}".format(exc=str(e)))
-    return OperatorCloud(cloud_config=cloud_config)
+    return OperatorCloud(cloud_config=cloud_config, strict=strict)
