@@ -328,9 +328,9 @@ class TestFloatingIP(base.TestCase):
         mock__neutron_list_fips.assert_called_once_with(None)
         mock__filter_list.assert_called_once_with(
             [], name_or_id=None,
-            filters={'port_id': None,
-                     'floating_network_id': self.mock_get_network_rep['id'],
-                     'tenant_id': 'proj-id'}
+            filters={'port': None,
+                     'network': self.mock_get_network_rep['id'],
+                     'location': {'project': {'id': 'proj-id'}}}
         )
         mock__neutron_create_fip.assert_called_once_with(
             network_id=self.mock_get_network_rep['id'],
@@ -366,9 +366,9 @@ class TestFloatingIP(base.TestCase):
         mock__neutron_list_fips.assert_called_once_with(None)
         mock__filter_list.assert_called_once_with(
             [], name_or_id=None,
-            filters={'port_id': None,
-                     'floating_network_id': self.mock_get_network_rep['id'],
-                     'tenant_id': 'proj-id'}
+            filters={'port': None,
+                     'network': self.mock_get_network_rep['id'],
+                     'location': {'project': {'id': 'proj-id'}}}
         )
         mock__neutron_create_fip.assert_called_once_with(
             network_id=self.mock_get_network_rep['id'],
@@ -413,11 +413,12 @@ class TestFloatingIP(base.TestCase):
             fake_server, ip_pool='my-network', reuse=False)
 
         mock__neutron_create_floating_ip.assert_called_once_with(
-            network_name_or_id='my-network', server=None, port=None,
+            network_name_or_id='my-network', server=fake_server, port=None,
             fixed_address=None, nat_destination=None, wait=False, timeout=60)
         mock_attach_ip_to_server.assert_called_once_with(
             server=fake_server, fixed_address=None,
-            floating_ip=fip, wait=False, timeout=mock.ANY)
+            floating_ip=fip, wait=False, timeout=mock.ANY,
+            nat_destination=None)
 
     @patch.object(OpenStackCloud, 'keystone_session')
     @patch.object(OpenStackCloud, '_neutron_create_floating_ip')
