@@ -15,7 +15,6 @@
 import mock
 import munch
 
-import glanceclient
 from heatclient import client as heat_client
 from neutronclient.common import exceptions as n_exc
 import testtools
@@ -77,20 +76,6 @@ class TestShade(base.TestCase):
         self.assertRaises(exc.OpenStackCloudException,
                           self.cloud.list_servers)
 
-    @mock.patch.object(cloud_config.CloudConfig, 'get_session')
-    @mock.patch.object(cloud_config.CloudConfig, 'get_legacy_client')
-    def test_glance_args(self, get_legacy_client_mock, get_session_mock):
-        session_mock = mock.Mock()
-        session_mock.get_endpoint.return_value = 'http://example.com/v2'
-        get_session_mock.return_value = session_mock
-        self.cloud.glance_client
-        get_legacy_client_mock.assert_called_once_with(
-            service_key='image',
-            client_class=glanceclient.Client,
-            interface_key=None,
-            pass_version_arg=True,
-        )
-
     @mock.patch.object(cloud_config.CloudConfig, 'get_session')
     @mock.patch.object(cloud_config.CloudConfig, 'get_legacy_client')
     def test_heat_args(self, get_legacy_client_mock, get_session_mock):
@@ -686,29 +671,25 @@ class TestShade(base.TestCase):
 
     @mock.patch.object(shade.OpenStackCloud, '_compute_client')
     def test__nova_extensions(self, mock_compute):
-        body = {
-            'extensions': [
-                {
-                    "updated": "2014-12-03T00:00:00Z",
-                    "name": "Multinic",
-                    "links": [],
-                    "namespace": "http://openstack.org/compute/ext/fake_xml",
-                    "alias": "NMN",
-                    "description": "Multiple network support."
-                },
-                {
-                    "updated": "2014-12-03T00:00:00Z",
-                    "name": "DiskConfig",
-                    "links": [],
-                    "namespace": "http://openstack.org/compute/ext/fake_xml",
-                    "alias": "OS-DCF",
-                    "description": "Disk Management Extension."
-                },
-            ]
-        }
-        mock_response = mock.Mock()
-        mock_response.json.return_value = body
-        mock_compute.get.return_value = mock_response
+        body = [
+            {
+                "updated": "2014-12-03T00:00:00Z",
+                "name": "Multinic",
+                "links": [],
+                "namespace": "http://openstack.org/compute/ext/fake_xml",
+                "alias": "NMN",
+                "description": "Multiple network support."
+            },
+            {
+                "updated": "2014-12-03T00:00:00Z",
+                "name": "DiskConfig",
+                "links": [],
+                "namespace": "http://openstack.org/compute/ext/fake_xml",
+                "alias": "OS-DCF",
+                "description": "Disk Management Extension."
+            },
+        ]
+        mock_compute.get.return_value = body
         extensions = self.cloud._nova_extensions()
         mock_compute.get.assert_called_once_with('/extensions')
         self.assertEqual(set(['NMN', 'OS-DCF']), extensions)
@@ -724,29 +705,25 @@ class TestShade(base.TestCase):
 
     @mock.patch.object(shade.OpenStackCloud, '_compute_client')
     def test__has_nova_extension(self, mock_compute):
-        body = {
-            'extensions': [
-                {
-                    "updated": "2014-12-03T00:00:00Z",
-                    "name": "Multinic",
-                    "links": [],
-                    "namespace": "http://openstack.org/compute/ext/fake_xml",
-                    "alias": "NMN",
-                    "description": "Multiple network support."
-                },
-                {
-                    "updated": "2014-12-03T00:00:00Z",
-                    "name": "DiskConfig",
-                    "links": [],
-                    "namespace": "http://openstack.org/compute/ext/fake_xml",
-                    "alias": "OS-DCF",
-                    "description": "Disk Management Extension."
-                },
-            ]
-        }
-        mock_response = mock.Mock()
-        mock_response.json.return_value = body
-        mock_compute.get.return_value = mock_response
+        body = [
+            {
+                "updated": "2014-12-03T00:00:00Z",
+                "name": "Multinic",
+                "links": [],
+                "namespace": "http://openstack.org/compute/ext/fake_xml",
+                "alias": "NMN",
+                "description": "Multiple network support."
+            },
+            {
+                "updated": "2014-12-03T00:00:00Z",
+                "name": "DiskConfig",
+                "links": [],
+                "namespace": "http://openstack.org/compute/ext/fake_xml",
+                "alias": "OS-DCF",
+                "description": "Disk Management Extension."
+            },
+        ]
+        mock_compute.get.return_value = body
         self.assertTrue(self.cloud._has_nova_extension('NMN'))
         self.assertFalse(self.cloud._has_nova_extension('invalid'))
 
